# sentence cut
轻量级的句子切分工具，以数值为核心，把较长的复杂句式（排比句、长难句）等切分为句子成分简单的短句，便于分析句中的数值类型。

## 安装

``` sh
pip install sentence_cut
```

## 使用
目前提供两种切分模式（粗粒度 和 细粒度）

参数method控制

    loose：粗粒度切分，只切分并列关系

        2020Q1~Q4，公司单季度营业收入分别为 12.99/16.44/19.82/21.56 亿元，同比增长，归母净利润 0.32/0.80/1.25/0.94 亿元

        切分为

        2020Q1公司单季度营业收入为12.99亿元，同比增长，归母净利润0.32亿元，
        2020Q2公司单季度营业收入为16.44亿元，同比增长，归母净利润0.80亿元，
        2020Q3公司单季度营业收入为19.82亿元，同比增长，归母净利润1.25亿元，
        2020Q4公司单季度营业收入为21.56亿元，同比增长，归母净利润0.94亿元，

    strict：细粒度切分，在粗粒度切分的基础上，进一步把同一主语的多个数值短语且分开

        报告期内，公司主要产品产量保持平稳，生产矿产金11.18吨，与上年同期比较减少了4.53%，与前年同期比较增加了7.12%。

        切分为

        报告期内，公司主要产品产量保持平稳，生产矿产金11.18吨, 
        报告期内，公司主要产品产量保持平稳，生产矿产金与上年同期比较减少了4.53%,
        报告期内，公司主要产品产量保持平稳，生产矿产金与前年同期比较增加了7.12%

代码示例如下：

```python
from sentence_cut import sentence_cut
SC = sentence_cut()
text = "20年公司前三季度实现收入/归母净利润为695.7/338.3亿元，同比+9.6%/11.1%；20Q3单季度实现收入/归母净利润为239.4/112.3亿元，同比+7.2%/6.9%。"


>>> SC.cut_sentence(text)
[
    '20年公司前三季度收入695.7亿元，同比+9.6%，',
    '20年公司前三季度归母净利润338.3亿元，同比11.1%，', 
    '20Q3单季度收入239.4亿元，同比+7.2%，', 
    '20Q3单季度归母净利润112.3亿元，同比6.9%，'
]

text = "20年公司前三季度实现收入/归母净利润为695.7/338.3亿元，同比+9.6%/11.1%；20Q3单季度实现收入/归母净利润为239.4/112.3亿元，同比+7.2%/6.9%；公司业绩延续上半年稳健增长态势，中秋国庆双节传统旺季带动需求快速增长，商超等直营渠道拓展稳步推进，产品结构持续优化，我们预计公司20-22年EPS为37.04/42.65/50.14元，维持“买入”。"

>>> SC.cut_sentence(text,method="strict")
[
    '20年公司前三季度收入695.7亿元', 
    '20年公司前三季度收入同比+9.6%', 
    '20年公司前三季度归母净利润338.3亿元', 
    '20年公司前三季度归母净利润同比11.1%', 
    '20Q3单季度收入239.4亿元', 
    '20Q3单季度收入同比+7.2%', 
    '20Q3单季度归母净利润112.3亿元', 
    '20Q3单季度归母净利润同比6.9%', 
    '公司业绩延续上半年稳健增长态势，中秋国庆双节传统旺季带动需求快速增长，商超等直营渠道拓展稳步推进，产品结构持续优化，我们预计公司2020年EPS为37.04元，维持“买入”', 
    '公司业绩延续上半年稳健增长态势，中秋国庆双节传统旺季带动需求快速增长，商超等直营渠道拓展稳步推进，产品结构持续优化，我们预计公司2021年EPS为42.65元，维持“买入”', 
    '公司业绩延续上半年稳健增长态势，中秋国庆双节传统旺季带动需求快速增长，商超等直营渠道拓展稳步推进，产品结构持续优化，我们预计公司2022年EPS为50.14元，维持“买入”'
]
```

